import { OffsetRange } from 'vs/editor/common/core/offsetRange';
import { Position } from 'vs/editor/common/core/position';
import { Range } from 'vs/editor/common/core/range';
import { ISequence } from 'vs/editor/common/diff/algorithms/diffAlgorithm';
import { ILinesDiffComputer, ILinesDiffComputerOptions, LineRangeMapping, LinesDiff, RangeMapping } from 'vs/editor/common/diff/linesDiffComputer';
export declare class AdvancedLinesDiffComputer implements ILinesDiffComputer {
    private readonly dynamicProgrammingDiffing;
    private readonly myersDiffingAlgorithm;
    computeDiff(originalLines: string[], modifiedLines: string[], options: ILinesDiffComputerOptions): LinesDiff;
    private computeMoves;
    private refineDiff;
}
export declare function lineRangeMappingFromRangeMappings(alignments: RangeMapping[], originalLines: string[], modifiedLines: string[], dontAssertStartLine?: boolean): LineRangeMapping[];
export declare function getLineRangeMapping(rangeMapping: RangeMapping, originalLines: string[], modifiedLines: string[]): LineRangeMapping;
export declare class LineSequence implements ISequence {
    private readonly trimmedHash;
    private readonly lines;
    constructor(trimmedHash: number[], lines: string[]);
    getElement(offset: number): number;
    get length(): number;
    getBoundaryScore(length: number): number;
    getText(range: OffsetRange): string;
    isStronglyEqual(offset1: number, offset2: number): boolean;
}
export declare class LinesSliceCharSequence implements ISequence {
    readonly lines: string[];
    readonly considerWhitespaceChanges: boolean;
    private readonly elements;
    private readonly firstCharOffsetByLineMinusOne;
    readonly lineRange: OffsetRange;
    private readonly additionalOffsetByLine;
    constructor(lines: string[], lineRange: OffsetRange, considerWhitespaceChanges: boolean);
    toString(): string;
    get text(): string;
    getText(range: OffsetRange): string;
    getElement(offset: number): number;
    get length(): number;
    getBoundaryScore(length: number): number;
    translateOffset(offset: number): Position;
    translateRange(range: OffsetRange): Range;
    /**
     * Finds the word that contains the character at the given offset
     */
    findWordContaining(offset: number): OffsetRange | undefined;
    countLinesIn(range: OffsetRange): number;
    isStronglyEqual(offset1: number, offset2: number): boolean;
    extendToFullLines(range: OffsetRange): OffsetRange;
}
export declare function findLastMonotonous<T>(arr: T[], predicate: (item: T) => boolean): T | undefined;
export declare function findFirstMonotonous<T>(arr: T[], predicate: (item: T) => boolean): T | undefined;
